#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
    hack by djj -_,- | good luck!
    date: 2018-03-02
"""
from ._textFileHandler import TextFileHandler
from ._jsonFileHandler import JsonFileHandler
