from setuptools import setup, find_packages


setup(
    name='PyTextSort',
    version='1.0.7',
    description='custom rules to sort a text file',
    author='djj',
    url='https://github.com/djjjj/py-text-sort',
    author_email='510620510@qq.com',
    packages=find_packages(),
)
